@@ -4,7 +4,7 @@ import joblib
 import numpy as np
 from pkg_resources import resource_filename
 import fire, warnings
-
+from datetime import datetime
 
 class Regbot:
   reg_model_path = resource_filename(__name__, 'finalized_model.h5') 
@@ -22,15 +22,19 @@ class Regbot:
       warnings.filterwarnings("ignore")
       loaded_model = joblib.load(open(f'{cls.reg_model_path}', 'rb'))
       return loaded_model
-
+  @classmethod
+  def getWeekDay(cls,utcdatetime):
+      date = datetime.fromisoformat(utcdatetime)
+      day = date.isoweekday()
+      return day
 
   @classmethod  
   def prepareInput(cls,opening,closing,utctime):
     avr = closing/(opening + closing)
     bvr = opening/(opening + closing)
     time = int(str(utctime).split(' ')[1].split(':')[0])
-
-    testdata = np.array([[avr,bvr,time]])
+    day = cls.getWeekDay(utctime)  
+    testdata = np.array([[avr,bvr,time,day]])
     with warnings.catch_warnings():
       warnings.filterwarnings("ignore")
       scaler = joblib.load(f'{cls.model_scaler_path}')
@@ -44,14 +48,14 @@ class Regbot:
     scalledInput = cls.prepareInput(opening,closing,utctime)
     with warnings.catch_warnings():
       warnings.filterwarnings("ignore")
-      return (cls.loadmodel().predict_proba(scalledInput)[:,1] > 0.6288659793814433).astype(int)[0]
+      return (cls.loadmodel().predict_proba(scalledInput)[:,1] > 0.60).astype(int)[0]
     
   @classmethod
   def sellSignalGenerator(cls,opening,closing,utctime):
     scalledInput = cls.prepareInput(opening,closing,utctime)
     with warnings.catch_warnings():
       warnings.filterwarnings("ignore")
-      return (cls.loadmodel().predict_proba(scalledInput)[:,1] <= 0.6288659793814433).astype(int)[0]
+      return (cls.loadmodel().predict_proba(scalledInput)[:,1] <= 0.60).astype(int)[0]
 
 
 
